
#include <kglobal.h>
#include <klocale.h>
#include <kconfig.h>
#include <kapplication.h>
// #include <kmessagebox.h>
#include <qimage.h>
#include <qlabel.h>
#include <kiconloader.h>
#include <dcopclient.h>
#include <kdebug.h>
#include "starter.h"


starter::starter(const QString& configFile, Type type, int actions, QWidget *parent, const char *name)
    : KPanelApplet(configFile, type, actions, parent, name)
{
    blocked = FALSE;
    mainView = new QLabel(this);
    client = new DCOPClient();
    if (!client->attach())
	    kdWarning() << "could not attach to dcop\n";
    
    KIconLoader* iLoader = KGlobal::iconLoader();
    QString pth = iLoader->iconPath("bStarter", KIcon::Small, true);
    if (pth)
        pixmap = QImage(pth);
    else
        {
        pixmap = QPixmap(22,22);
        pixmap.fill(Qt::black);
        }
    pth = QString();
    pth = iLoader->iconPath("bStarter_hover", KIcon::Small, true);
    if (pth)
        hoverPixmap = QImage(pth);
    else
        {
        hoverPixmap = QPixmap(22,22);
        hoverPixmap.fill(Qt::black);
        }
    pth = QString();
    pth = iLoader->iconPath("bStarter_down", KIcon::Small, true);
    if (pth)
        downPixmap = QImage(pth);
    else
        {
        downPixmap = QPixmap(22,22);
        downPixmap.fill(Qt::white);
        }
    int wd = pixmap.width();
    int ht = pixmap.height();
    if (wd < hoverPixmap.width()) wd = hoverPixmap.width();
    if (wd < downPixmap.width()) wd = downPixmap.width();
    if (ht < hoverPixmap.height()) ht = hoverPixmap.height();
    if (ht < downPixmap.height()) ht = downPixmap.height();
    setFixedSize(wd,ht);
    mainView->setFixedSize(wd,ht);
    mainView->move(0,0);
    move(parent->x(),parent->y());
    mainView->installEventFilter(this);
    mainView->setPixmap(pixmap);
    mainView->show();
}


starter::~starter()
{
   if (client) delete client;
    m_painter.end();
}


void starter::preferences()
{
   KApplication::startServiceByDesktopName("kmenuedit", QStringList(), 0, 0, 0, "", true);
}

int starter::widthForHeight(int height) const
{
    return mainView->width();
}

int starter::heightForWidth(int width) const
{
    return mainView->height();
}

bool starter::eventFilter( QObject*, QEvent *e )
{
    switch (e->type())
    {
        case QEvent::Enter:
        {
            mainView->setPixmap(hoverPixmap);
            mainView->repaint();
            return TRUE;
        }
        case QEvent::Leave:
        {
            blocked = FALSE;
            mainView->setPixmap(pixmap);
            mainView->repaint();
            return TRUE;
        }
    /*        case QEvent::Paint:
        {
            mainView->erase();
            m_painter.begin(mainView);
            m_painter.drawPixmap(0,0,(state==Down)?downPixmap:(state==Hover)?hoverPixmap:pixmap);
            m_painter.end();
            return TRUE;
        }*/
        case QEvent::MouseButtonPress:
        {
            if (((QMouseEvent*)e)->button() != Qt::LeftButton)
                return TRUE;
            mainView->setPixmap(downPixmap);
            mainView->repaint();
            return TRUE;
        }
        case QEvent::MouseButtonRelease:
        {
            if (((QMouseEvent*)e)->button() != Qt::LeftButton)
                return FALSE;
            if (mainView->hasMouse())
                {
                mainView->setPixmap(hoverPixmap);
                mainView->repaint();
                if (!blocked)
                    {
                    blocked = TRUE;
                    QByteArray data;
                    QDataStream arg(data, IO_WriteOnly);
                    arg << mapToGlobal(QPoint(x()-5,y()+height()));
                    if (!client->send("kicker", "kicker", "popupKMenu(QPoint)", data))
                        kdWarning() << "Could not send DCOP command\n";
                    }
                else
                    blocked = FALSE;
                }
            else
                {
                blocked = FALSE;
                    mainView->setPixmap(pixmap);
                mainView->repaint();
                }
            return TRUE;
        }
        default:
            return FALSE;
    }
}

extern "C"
{
    KPanelApplet* init( QWidget *parent, const QString& configFile)
    {
       KGlobal::locale()->insertCatalogue("baghirastarter");
       return new starter(configFile, KPanelApplet::Normal,
                                 KPanelApplet::Preferences,
                                 parent, "baghirastarter");
    }
}
